
def task_xxx1():
    pass

def task_yyy2():
    pass

def bad_seed():
    pass


